@@ -1,10 +1,9 @@
 package Data::Printer::Filter::PDL;
-$Data::Printer::Filter::PDL::VERSION = '0.007';
+$Data::Printer::Filter::PDL::VERSION = '1.000';
 use strict;
 use warnings;
 
 use Data::Printer::Filter;
-use Term::ANSIColor;
 
 filter 'PDL', \&pdl_filter;
 filter 'PDL::Char', \&pdl_filter;
@@ -12,8 +11,39 @@ filter 'PDL::Complex', \&pdl_filter;
 
 use constant MSG_TOOLONG => 'too long to print';
 
+use constant COLORS => {
+  filter_pdl_data_number => { fallback => 'number', color => 'magenta' },
+  filter_pdl_data_brackets => { fallback => 'brackets', color => 'bright_green' },
+
+  filter_pdl_data_message => { fallback => 'string', color => 'cyan' },
+
+  filter_pdl_type => { fallback => 'class', color => 'black on_red' },
+
+  filter_pdl_shape_number => { fallback => 'array', color => 'cyan' },
+  filter_pdl_shape_brackets => { fallback => 'brackets', color => 'bright_green' },
+
+  filter_pdl_nelem => { color => 'bright_yellow' },
+
+  filter_pdl_min => { color => 'bright_red' },
+  filter_pdl_max => { color => 'bright_blue' },
+
+  filter_pdl_bad_true => { color => 'red' },
+  filter_pdl_bad_false => { color => 'green' },
+};
+
+# _get_color_pair
+sub _gcp {
+  my ($ddp, $name) = @_;
+  my $color_spec = %{ COLORS() }{$name};
+  my $default_color = $color_spec->{color};
+  if( exists $color_spec->{fallback} && ( my $fallback_color = $ddp->theme->color_for($color_spec->{fallback}) ) ) {
+    $default_color = $fallback_color;
+  }
+  ( $name, $default_color );
+}
+
 sub pdl_filter {
-  my ($self, $props) = @_;
+  my ($self, $ddp) = @_;
 
   ################################################
   # Get Data, Build Structure                    #
@@ -23,73 +53,74 @@ sub pdl_filter {
   if($self->nelem <= $PDL::toolongtoprint) { # NOTE this logic is already in PDL, so this may be superfluous
     (my $string = $self->string) =~ s,^\n|\n$,,gs;
     # TODO if PDL::Char also show $p->PDL::string()
-    push @data, [ 'Data' => color_pdl_string($props, ['magenta'], $string) ];
+    push @data, [ 'Data' => color_pdl_string($ddp, $string, 'data') ];
   } else {
-    push @data, [ 'Data' => color_pdl_string($props, ['cyan'], MSG_TOOLONG) ];
+    push @data, [ 'Data' => $ddp->maybe_colorize(MSG_TOOLONG, _gcp($ddp, 'filter_pdl_data_message') ) ];
   }
 
   # type
-  push @data, [ Type => opt_colored($props, ['black on_red'], $self->type->realctype) ];
+  push @data, [ Type => $ddp->maybe_colorize($self->type->realctype, _gcp($ddp, 'filter_pdl_type') ) ];
 
   # shape
-  push @data, [ Shape => color_pdl_string($props, ['cyan'], $self->shape->string) ];
+  push @data, [ Shape => color_pdl_string($ddp, $self->shape->string, 'shape') ];
 
   # elements
-  push @data, [ Nelem => opt_colored($props, ['bright_yellow'], $self->nelem) ];
+  push @data, [ Nelem => $ddp->maybe_colorize($self->nelem, _gcp($ddp, 'filter_pdl_nelem')) ];
 
   # min and max
   my ($min, $max) = $self->minmax;
-  push @data, [ Min => opt_colored($props, ['bright_red'], $min) ];
-  push @data, [ Max => opt_colored($props, ['bright_blue'], $max) ];
+  push @data, [ Min => $ddp->maybe_colorize($min, _gcp($ddp, 'filter_pdl_min') ) ];
+  push @data, [ Max => $ddp->maybe_colorize($max, _gcp($ddp, 'filter_pdl_max') ) ];
 
   # bad?
   my $bad_flag = $self->badflag;
   $self->check_badflag;
-  push @data, [ Badflag => color_bad_bool($props, $bad_flag) ];
-  push @data, [ 'Has Bads' =>  color_bad_bool($props, $self->badflag) ];
+  push @data, [ Badflag => color_bad_bool($ddp, $bad_flag) ];
+  push @data, [ 'Has Bads' =>  color_bad_bool($ddp, $self->badflag) ];
   $self->badflag($bad_flag);
 
   #####################
   # Format the Output #
   #####################
-  $props ||= {};
-  my $indent = defined $props->{indent} ? $props->{indent} : 4;
+  my $data = $ddp->maybe_colorize( ref($self), 'class' );
+  $data .= $ddp->maybe_colorize( " {", 'brackets' );
+
+  $ddp->indent;
+  $data .= $ddp->newline();
 
   my $max_tag_length = List::Util::max map { length $_->[0] } @data;
-  my $tag_format = ' ' x $indent . '%-' . $max_tag_length . 's : ';
+  my $tag_format = $ddp->maybe_colorize( '%-' . $max_tag_length . 's' , 'hash') . ' : ';
   (my $empty_tag = sprintf($tag_format, "")) =~ s,:, ,;
   my @formatted =
     map {
-      $_->[1] =~ s,\n,@{[newline()]}$empty_tag,gs;
+      $_->[1] =~ s,\n,@{[$ddp->newline()]}$empty_tag,gs;
       sprintf($tag_format, $_->[0]) . $_->[1]
     }
     @data;
 
-  my $data = ref($self) . " {" . newline();
-  $data .= join newline(), @formatted;
-  $data .= newline()."}";
+  $data .= join $ddp->newline(), @formatted;
+
+  $ddp->outdent;
+  $data .= $ddp->newline();
+  $data .= $ddp->maybe_colorize( "}", 'brackets' );
 
   return $data;
 };
 
 sub color_pdl_string {
-  my ($props, $color, $pdl) = @_;
-  $pdl =~ s/\[(.*)\]/"[".opt_colored($props, $color, $1)."]"/eg;
-  $pdl =~ s/^([^\[]+)$/opt_colored($props, $color, $1)/eg;
-  $pdl =~ s/^\s*\[|\]$/opt_colored($props, ['bright_green'], $&)/emg;
+  my ($ddp, $pdl, $type) = @_;
+  $pdl =~ s/\[(.*)\]/"[".$ddp->maybe_colorize($1, _gcp($ddp, "filter_pdl_${type}_number"))."]"/eg;
+  $pdl =~ s/^([^\[]+)$/$ddp->maybe_colorize($1, _gcp($ddp, "filter_pdl_${type}_number"))/eg;
+  $pdl =~ s/^\s*\[|\]$/$ddp->maybe_colorize($&, _gcp($ddp, "filter_pdl_${type}_brackets"))/emg;
   return $pdl;
 }
 
 sub color_bad_bool {
-  my ($props, $bool) = @_;
-  return $bool ? opt_colored($props, ['red'],"Yes") : opt_colored($props, ['green'],"No");
-}
-
-sub opt_colored {
-  my $props = shift;
-  my ($color, $string) = @_;
-  return $string unless $props->{colored};
-  colored(@_);
+  my ($ddp, $bool) = @_;
+  $ddp->maybe_colorize(
+    $bool ? "Yes" : "No",
+    _gcp($ddp, $bool ? 'filter_pdl_bad_true' : 'filter_pdl_bad_false' )
+  )
 }
 
 
@@ -107,14 +138,14 @@ Data::Printer::Filter::PDL
 
 =head1 VERSION
 
-version 0.007
+version 1.000
 
 =head1 SYNOPSIS
 
     use PDL;
     use Data::Printer;
 
-    my $pdl = sequence(10,10);
+    my $pdl = sequence(2,2);
     p $pdl;
 
     __END__
@@ -150,14 +181,9 @@ when the contents of piddles with many elements are displayed.
 =head1 EXAMPLES
 
 You will want to configure L<Data::Printer> to use this module by creating a
-.dataprinter file in your $HOME directory:
+C<.dataprinter> file in your $HOME directory:
 
-    {
-        colored => 1,
-        filters => {
-          -external => [ 'PDL' ],
-        }
-    };
+    filters = PDL
 
 If you are using this module with the plugin
 L<Devel::REPL::Plugin::DataPrinter>, you may want to add the following to your
@@ -166,14 +192,15 @@ in L<Devel::REPL>:
 
     $_REPL->dataprinter_config({
         stringify => {
-            'PDL::Char' => 0,
+            'PDL'          => 0,
+            'PDL::Char'    => 0,
             'PDL::Complex' => 0,
         },
     });
 
 =head1 BUGS
 
-Report bugs and submit patches to the repository on L<GitHub|https://github.com/zmughal/Data-Printer-Filter-PDL>.
+Report bugs and submit patches to the repository on L<GitHub|https://github.com/EntropyOrg/p5-Data-Printer-Filter-PDL>.
 
 =head1 SEE ALSO
 
